## dbt-athena 1.9.4 - April 28, 2025

### Features

- Add high availability when doing full refresh on existing iceberg table ([#458](https://github.com/dbt-labs/dbt-adapters/issues/458))

### Contributors
- [@alex-antonison](https://github.com/alex-antonison) ([#458](https://github.com/dbt-labs/dbt-adapters/issues/458))
